@@ -35,7 +35,6 @@
 #include <pango/pango-attributes.h>
 #include <pango/pango-break.h>
 #include <pango/pango-context.h>
-#include <pango/pangoft2.h>
 #include <string.h>
 
 PangoAttrList *
@@ -63,42 +62,6 @@ eel_pango_attr_list_apply_global_attribute (PangoAttrList *attr_list,
 	return new_attr_list;
 }
 
-static void
-apply_global_attribute (PangoLayout *layout, PangoAttribute *attr)
-{
-	PangoAttrList *attr_list;
-	PangoAttrList *old_attr_list;
-
-	old_attr_list = pango_layout_get_attributes (layout);
-	attr_list = eel_pango_attr_list_apply_global_attribute (old_attr_list, attr);
-	pango_layout_set_attributes (layout, attr_list);
-	pango_attr_list_unref (attr_list);
-}
-
-void
-eel_pango_layout_set_underline (PangoLayout *layout, PangoUnderline underline)
-{
-	apply_global_attribute (layout, pango_attr_underline_new (underline));
-}
-
-void
-eel_pango_layout_set_weight (PangoLayout *layout, PangoWeight weight)
-{
-	apply_global_attribute (layout, pango_attr_weight_new (weight));
-}
-
-void
-eel_pango_layout_set_font_desc_from_string (PangoLayout *layout, const char *str)
-{
-	PangoFontDescription *desc;
-
-	desc = pango_font_description_from_string (str);
-	pango_layout_set_font_description (layout, desc);
-	pango_font_description_free (desc);
-}
-
-
-
 #define ELLIPSIS "..."
 
 /* Caution: this is an _expensive_ function */
@@ -454,7 +417,6 @@ eel_pango_layout_set_text_ellipsized (PangoLayout  *layout,
 		break;
 	default:
 		g_return_if_reached ();
-		s = NULL;
 	}
 	
 	pango_layout_set_text (layout, s, -1);
@@ -462,49 +424,6 @@ eel_pango_layout_set_text_ellipsized (PangoLayout  *layout,
 	g_free (s);
 }
 
-/**
- * eel_pango_layout_fit_to_dimensions:
- * @layout: a pango layout
- * @max_width: the maximum width allowed or -1 to match only height
- * @max_height: the maximum height allowed or -1 to match only width
- * 
- *    This method adjusts the font attributes of the simple
- * string in @layout until it fits inside the desired @max_size.
- * 
- * Return value: the resulting dimensions.
- **/
-PangoRectangle
-eel_pango_layout_fit_to_dimensions (PangoLayout *layout,
-				    int          max_width,
-				    int          max_height)
-{
-	gint size;
-	PangoContext *context;
-	PangoRectangle logical_rect = { 0 };
-	PangoFontDescription *font_desc;
-
-	g_return_val_if_fail (PANGO_IS_LAYOUT (layout), logical_rect);
-
-	context = pango_layout_get_context (layout);
-	font_desc = pango_font_description_copy (pango_context_get_font_description (context));
-	size = pango_font_description_get_size (font_desc);
-
-	while (size > 0) {
-		pango_font_description_set_size (font_desc, size);
-		pango_layout_set_font_description (layout, font_desc);
-		pango_layout_get_pixel_extents (layout, NULL, &logical_rect);
-
-		if (!((((max_width > 0 && logical_rect.width > max_width) || max_width < 0) &&
-		       ((max_height > 0 && logical_rect.height > max_height) || max_height < 0))))
-			break;
-		
-		size -= PANGO_SCALE / 2;
-	}
-
-	pango_font_description_free (font_desc);
-	
-	return logical_rect;
-}
 
 int
 eel_pango_font_description_get_largest_fitting_font_size (const PangoFontDescription *font_desc,
@@ -551,21 +470,6 @@ eel_pango_font_description_get_largest_fitting_font_size (const PangoFontDescrip
 }
 
 
-PangoContext *
-eel_pango_ft2_get_context (void)
-{
-	PangoContext *context;
-	double dpi_x, dpi_y;
-			
-	dpi_x = gdk_screen_width () * 25.4 / gdk_screen_width_mm ();
-	dpi_y = gdk_screen_height () * 25.4 / gdk_screen_height_mm ();
-	context = pango_ft2_get_context (dpi_x, dpi_y);
-
-	pango_context_set_language (context, gtk_get_default_language ());
-
-	return context;
-}
-
 #if !defined (EEL_OMIT_SELF_CHECK)
 
 static PangoContext *
